@@ -1,9 +1,12 @@
 /* $RoughId: sha2init.c,v 1.3 2001/07/13 20:00:43 knu Exp $ */
-/* $Id: sha2init.c 47745 2014-09-30 08:29:02Z nobu $ */
+/* $Id$ */
 
-#include "digest.h"
+#include <ruby/ruby.h>
+#include "../digest.h"
 #if defined(SHA2_USE_OPENSSL)
 #include "sha2ossl.h"
+#elif defined(SHA2_USE_COMMONDIGEST)
+#include "sha2cc.h"
 #else
 #include "sha2.h"
 #endif
@@ -32,18 +35,14 @@ void
 Init_sha2(void)
 {
     VALUE mDigest, cDigest_Base;
-    ID id_metadata;
+    ID id_metadata = rb_id_metadata();
 
 #define DECLARE_ALGO_CLASS(bitlen) \
     VALUE cDigest_SHA##bitlen;
 
     FOREACH_BITLEN(DECLARE_ALGO_CLASS)
 
-    rb_require("digest");
-
-    id_metadata = rb_intern("metadata");
-
-    mDigest = rb_path2class("Digest");
+    mDigest = rb_digest_namespace();
     cDigest_Base = rb_path2class("Digest::Base");
 
 #define DEFINE_ALGO_CLASS(bitlen) \
